import {
  axisLeft,
  axisBottom,
  scaleLinear,
  extent
} from 'd3'; 

export const scatterPlot = (selection, props) => {
  
    const {
      data,
      colorValue,
      colorScale,
      selectedColorValue,
      width,
      height,
      margin,
      title,
      xValue,
      xAxisLabel,
      yValue,
      yAxisLabel, 
      circleRadius,
      innerWidth,
      innerHeight
  } = props;
  
  console.log(xAxisLabel);
  
  /*const g = selection.selectAll('.container').data([null]);
  const gEnter = g
    .enter().append('g')
      .attr('class', 'container');
  gEnter
    .merge(g)
      .attr('transform',
        `translate(${margin.left},${margin.top})`
      );*/
  
  const g = selection.selectAll('.container').data([null]);
  const gEnter = g
    .enter().append('g')
      .attr('class', 'container');
  gEnter
    .merge(g)
      .attr('transform',
        `translate(${margin.left},${margin.top})`
      )
  
  gEnter.append('text')
    .merge(g.select('.title'))
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
  
   const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
 /* const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
 */ 
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  /*const gUpdate = selection.selectAll('g').data([null]);  
  const gEnter = gUpdate.enter().append('g')
  const g = gUpdate.merge(gEnter); */
  
  const yAxisG = g.select('.y-axis');
  const yAxisGEnter = gEnter
    .append('g')
      .attr('class', 'y-axis');
  
  yAxisG.merge(yAxisGEnter)
      .call(yAxis)
    .selectAll('.domain').remove();

  yAxisGEnter.append('text')
    .attr('class', 'axis-label')
    .attr('y', -73)
    .attr('fill', 'black')
    .attr('transform', `rotate(-90)`)
    .attr('text-anchor', 'middle')
  .merge(yAxisG.select('.axis-label'))
    .attr('x', -innerHeight / 2)
    .text(yAxisLabel);
  
  
  
 /* gEnter
    .attr('transform', `translate(${margin.left},${margin.top})`); 
  
  const yAxisG = gEnter.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
    yAxisG.append('text')
      .attr('class', 'axis-label') 
      .attr('y', -margin.left/2)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel); */
    
  const xAxisG = g.select('.x-axis');
  const xAxisGEnter = gEnter
    .append('g')
      .attr('class', 'x-axis');
  
  xAxisG
    .merge(xAxisGEnter)
      .attr('transform', `translate(0,${innerHeight})`)
      .call(xAxis)
      .selectAll('domain').remove();
  
  xAxisGEnter.append('text')
    .attr('class', 'axis-label')
    .attr('y', 75)
    .attr('fill', 'black')
  .merge(xAxisG.select('.axis-label'))
    .attr('x', innerWidth / 2)
    .text(xAxisLabel);
  
    
    
  
  /*const xAxisG = gEnter.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG
    .append('text')
      .attr('class', 'axis-label')
    .merge(xAxisG) 
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);*/
    
  
  let datapoints = g.merge(gEnter)
    .selectAll('circle').data(data);

  
  let datapointsEnter = datapoints
    .enter().append('circle')
      .attr('class','datapoints')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
      .attr('fill',d => colorScale(colorValue(d)))
    .merge(datapoints)
    .transition().duration(50)
      .delay((d,i) => i *10)
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
 /* const datapointsEnter = datapoints
    .enter().append('circle')
      .attr('class', 'datapoints')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius)
      .attr('fill',d => colorScale(colorValue(d))); */
  
  datapoints 
    .merge(datapointsEnter) 
      .attr('opacity',d =>
         (!selectedColorValue) || (selectedColorValue == colorValue(d))
              ? 1
              : 0.25
        )
     .classed('highlighted', d => 
       selectedColorValue && selectedColorValue === colorValue(d)) 
}